@@ -75,7 +75,7 @@ class Preprocessor(object):
         """
         Reads a cache file into LS_CACHE
         """
-        logger.info('Reading ls cache file %s', len(cache_file))
+        logger.info('Reading ls cache file %s', cache_file)
         with open(cache_file, 'r') as f:
             cls.LS_CACHE = json.load(f)
 
@@ -375,9 +375,9 @@ class Preprocessor(object):
             logger.debug('BATCHMODE: %s --> %s', path, osp.basename(path))
             path = osp.basename(path)
         else:
-            if not osp.isabs(path):
+            if not seutils.has_protocol(path) and not osp.isabs(path):
                 if hasattr(self, 'filename'):
-                    # Make sure path is relative to the file that is preprocessed
+                    # Make sure path is relative to the python file that is preprocessed
                     path = osp.abspath(osp.join(osp.dirname(self.filename), path))
                 else:
                     path = osp.abspath(path)
